naked library
Classes
-
NakedAccordion<
T> - A fully customizable accordion with no default styling.
-
NakedAccordionController<
T> - Controller that manages the state of an accordion.
-
NakedAccordionItem<
T> - An individual item in a NakedAccordion.
- NakedButton
- A fully customizable button with no default styling.
- NakedCheckbox
- A fully customizable checkbox with no default styling.
- NakedMenu
- A fully customizable menu with no default styling.
- NakedMenuItem
- An individual menu item that can be selected.
- NakedPortal
-
NakedRadio<
T> - A fully customizable radio button with no default styling.
-
NakedRadioGroup<
T> - A context provider for a radio group that manages a single selection across multiple radio buttons.
-
NakedRadioGroupScope<
T> - Internal InheritedWidget that provides radio group state to child radio buttons.
-
NakedSelect<
T> - A fully customizable select/dropdown widget with no default styling.
-
NakedSelectInherited<
T> - An InheritedWidget that provides access to the selected values in a NakedSelect.
-
NakedSelectItem<
T> - A selectable item within the dropdown menu.
- NakedSelectTrigger
- A customizable trigger button that controls the select dropdown.
- NakedSlider
- A fully customizable slider with no default styling.
- NakedTab
- An individual tab trigger in a NakedTabs component.
- NakedTabGroup
- A fully customizable tabs component with no default styling.
- NakedTabList
- A container for tab triggers in a NakedTabs component.
- NakedTabPanel
- A panel that displays content for a specific tab in a NakedTabs component.
- NakedTabsScope
- The scope that provides tabs state to its descendants.
- NakedTextField
- A fully customizable text field with no default styling or decoration.
- NakedTooltip
- A fully customizable tooltip with no default styling.
- OverlayChildLifecycle
- PositionConfig
Mixins
-
OverlayChildLifecycleMixin<
T extends StatefulWidget>
Functions
-
showNakedDialog<
T> ({required BuildContext context, required WidgetBuilder builder, required Color barrierColor, bool barrierDismissible = true, String? barrierLabel, RouteSettings? routeSettings, Offset? anchorPoint, Duration transitionDuration = const Duration(milliseconds: 400), RouteTransitionsBuilder? transitionBuilder, bool requestFocus = true, TraversalEdgeBehavior? traversalEdgeBehavior}) → Future< T?>
Typedefs
- NakedAccordionTriggerBuilder = Widget Function(BuildContext context, bool isExpanded, VoidCallback toggle)
- OverlayChildLifecycleCallback = void Function(OverlayChildLifecycleState state)